Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(751)

Unified Diff: chrome/browser/chromeos/gdata/gdata_test_util.h

Issue 10877005: Rename GDataCache* to DriveCache* (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/chromeos/gdata/gdata_system_service.cc ('k') | chrome/browser/chromeos/gdata/gdata_util.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/gdata/gdata_test_util.h
diff --git a/chrome/browser/chromeos/gdata/gdata_test_util.h b/chrome/browser/chromeos/gdata/gdata_test_util.h
index 433d6090c83ca3b00793d4c9b81285e864174787..93ce2062a7650f8c47b4556da818bc7a6643728f 100644
--- a/chrome/browser/chromeos/gdata/gdata_test_util.h
+++ b/chrome/browser/chromeos/gdata/gdata_test_util.h
@@ -30,7 +30,7 @@ namespace test_util {
void RunBlockingPoolTask();
// This is a bitmask of cache states in DriveCacheEntry. Used only in tests.
-enum TestGDataCacheState {
+enum TestDriveCacheState {
TEST_CACHE_STATE_NONE = 0,
TEST_CACHE_STATE_PINNED = 1 << 0,
TEST_CACHE_STATE_PRESENT = 1 << 1,
@@ -39,7 +39,7 @@ enum TestGDataCacheState {
TEST_CACHE_STATE_PERSISTENT = 1 << 4,
};
// Converts |cache_state| which is a bit mask of TestGDataCacheState, to a
// DriveCacheEntry.
DriveCacheEntry ToCacheEntry(int cache_state);
« no previous file with comments | « chrome/browser/chromeos/gdata/gdata_system_service.cc ('k') | chrome/browser/chromeos/gdata/gdata_util.h » ('j') | no next file with comments »
@@ -39,7 +39,7 @@ enum TestGDataCacheState {
TEST_CACHE_STATE_PERSISTENT = 1 << 4,
};
-// Converts |cache_state| which is a bit mask of TestGDataCacheState, to a
+// Converts |cache_state| which is a bit mask of TestDriveCacheState, to a
// DriveCacheEntry.
DriveCacheEntry ToCacheEntry(int cache_state);

Powered by Google App Engine
This is Rietveld 408576698